import datetime
import os
import time

import tutils

# Line format:
# "filename" size date (time)?

def read_config(in_filename):
    for line in file(in_filename, 'rt'):
        line = line.strip()
        if not line:
            continue
        assert line[0] == '"'

        fn_end = line.index('"', 1)
        filename = line[1:fn_end]

        restline = line[fn_end+1:]
        tokens = restline.split()
        assert len(tokens) in (2, 3)

        size = int(tokens[0])
        moddate = tutils.convdate(tokens[1])
        if len(tokens) == 3:
            hour, minute = [int(s) for s in tokens[2].split(':')]
        else:
            hour, minute = 12, 0
        modtime = datetime.time(hour, minute)
        mod_timestamp = datetime.datetime.combine(moddate, modtime)

        yield (filename, size, mod_timestamp)

def make_file(filename, size, modtime):
    directory = os.path.dirname(filename)
    if directory and (not os.path.exists(directory)):
        os.makedirs(directory)

    outfile = file(filename, 'wt')
    outfile.write('x'*size)
    outfile.close()

    mod_timestamp = time.mktime(modtime.timetuple())
    os.utime(filename, (mod_timestamp, mod_timestamp))


def main(args):
    if not args:
        print 'Usage: make_dir_struct <config file>'
        return

    for filename, size, modtime in read_config(args[0]):
        print filename, size, modtime
        make_file(filename, size, modtime)


if __name__=='__main__':
    import sys
    main(sys.argv[1:])